@@ -8,11 +8,12 @@ use Archive::Har::Browser();
 use Archive::Har::Page();
 use Archive::Har::Entry();
 use XML::LibXML();
-use Compress::Zlib();
+use IO::Compress::Gzip();
+use IO::Uncompress::Gunzip();
 use JSON();
 use overload '""' => 'string';
 
-our $VERSION = 0.17;
+our $VERSION = 0.18;
 
 sub new {
     my ( $class, $params ) = @_;
@@ -33,10 +34,15 @@ sub _init {
 
 sub gzip {
     my ( $self, $gzipped ) = @_;
-    my $old = Compress::Zlib::memGzip( $self->string() )
-      or Carp::croak('Failed to gzip HAR archive');
+    my $uncompressed = $self->string();
+    my $old;
+    IO::Compress::Gzip::gzip( \$uncompressed, \$old,
+        -Level => IO::Compress::Gzip::Z_BEST_COMPRESSION() )
+      or
+      Carp::croak("Failed to gzip HAR archive:$IO::Compress::Gzip::GzipError");
     if ( defined $gzipped ) {
-        my $string = Compress::Zlib::memGunzip($gzipped)
+        my $string;
+        IO::Uncompress::Gunzip::gunzip( \$gzipped, \$string )
           or Carp::croak('Failed to gunzip HAR archive');
         $self->string($string);
     }
@@ -482,7 +488,7 @@ Archive::Har - Provides an interface to HTTP Archive (HAR) files
 
 =head1 VERSION
 
-Version 0.17
+Version 0.18
 
 =for stopwords xml gzip stringified HAR gzipped gzipping JSON hashref gunzipping
 
